@@ -119,7 +119,7 @@ modify it under the same terms as Perl itself.
 #####################################################################
 
 @ISA = qw(WWW::Search::Scraper Exporter);
-$VERSION = sprintf("%d.%02d", q$Revision: 1.7 $ =~ /(\d+)\.(\d+)/);
+$VERSION = sprintf("%d.%02d", q$Revision: 1.8 $ =~ /(\d+)\.(\d+)/);
 
 use WWW::Search::Scraper(qw(1.48 trimTags));
 
@@ -178,6 +178,26 @@ my $scraperFrame =
 ];
 
 
+sub testParameters {
+    my ($self) = @_;
+
+    if ( ref $self ) {
+        $self->{'isTesting'} = 1;
+        $self->techiesLocation('bayarea'); # Set location for test.pl
+    }
+
+    # 'POST' style scraperFrames can't be tested cause of a bug in WWW::Search(2.2[56]) !
+    my $isNotTestable = WWW::Search::Scraper::isGlennWood()?0:(($WWW::Search::VERSION eq '2.28') or ($WWW::Search::VERSION eq '2.26'));
+    return {
+                 'isNotTestable' => $isNotTestable
+                ,'testNativeQuery' => 'Java'
+                ,'expectedOnePage' => 9
+                ,'expectedMultiPage' => 11
+                ,'expectedBogusPage' => 0
+                ,'usesPOST' => 0
+           };
+}
+
 # Access methods for the structural declarations of this Scraper engine.
 sub scraperQuery  { $scraperQuery }
 sub scraperRequest{ return $_[0]->request() }
