@@ -1,8 +1,10 @@
 # Before `make install' is performed this script should be runnable with
 # `make test'. After `make install' it should work as `perl test.pl'
 
+use WWW::Search::Scraper(qw(2.15));
+
 use ExtUtils::testlib;
-$VERSION = sprintf("%d.%02d", q$Revision: 1.8 $ =~ /(\d+)\.(\d+)/);
+$VERSION = sprintf("%d.%02d", q$Revision: 1.9 $ =~ /(\d+)\.(\d+)/);
 
 ######################### We start with some black magic to print on failure.
 
@@ -14,6 +16,13 @@ END {#print STDOUT "1..1\nnot ok 1\n" unless $loaded;
     }
 
 my $iTest = 0;
+my $countErrorMessages = 0;
+my $countWarningMessages = 0;
+
+
+use FileHandle;
+    my $traceFile = new FileHandle('>test.trace') or die "Can't open test.trace file: $!";
+    select ($traceFile); $| = 1; select STDOUT;
 
 open TMP, "<MANIFEST";
 my @modules;
@@ -23,29 +32,38 @@ while (<TMP>) {
         next if $1 eq 'Response';         # This one's not an engine.
         next if $1 eq 'FieldTranslation'; # This one's not an engine.
         next if $1 eq 'TidyXML';          # This one's not an engine.
-        next if $1 eq 'Dogpile';          # We're not ready to test TidyXML modules, yet.
 
-#       next if $1 eq 'Sherlock';    # We're not smart enough to test Sherlock, yet!
-        next if $1 eq 'apartments';  # went flippo - I'll fix this later.
-        next if $1 eq 'BAJobs';     # BAJobs is sick this month - I'll fix later.
-        next if $1 eq 'guru';        # This one doesn't work today, gdw.2001.08.22
-        next if $1 eq 'HotJobs';     # HotJobs changed a lot - I'll fix this later.
-        next if $1 eq 'JustTechJobs'; # went flippo - I'll fix this later; also, not ready for v2.01 ({'whichTech'}).
-        next if $1 eq 'theWorksUSA'; # This one still has a problem (looping).
+        my $testParameters;
+        eval "use WWW::Search::Scraper::$1; \$testParameters = &WWW::Search::Scraper::$1::testParameters()";
+        # print $@; $@ just means the Scraper sub-class doesn't have a testParameters() method, yet.
+        unless ( 0 and WWW::Search::Scraper::isGlennWood() ) {
+            if ( $testParameters ) {
+                if ( $testParameters->{'isNotTestable'} ) {
+                    TRACE(1, "$1 will not be tested: $testParameters->{'isNotTestable'}\n");
+                    next;
+                }
+                # we're making this exception in 2.16 because WWW::Search seems to be broken on
+                #    http://testers.cpan.org/search?request=mac&mac=129
+                #    linux 2.2.14-5.0 i686-linux
+                if ( $VERSION eq '1.10' )
+                {
+    #                if ( $testParameters->{'usesPOST'} ) {
+    #                    print STDERR "Skipped $1 in this test: test.pl v$VERSION can not test modules that use the 'POST' method (see WWW::Search(2.26)\n";
+    #                    next;
+    #                }
+                }
+            }
+        }
         push @modules, $1;
     }
 }
 close TMP;
-
-    my $testCount = 1 + scalar(@modules) * 4;
+    
+    my $testCount = 2 + scalar(@modules) * 4;
     print STDOUT "1..$testCount\n";
     $iTest++;
     print STDOUT "ok $iTest\n";
     
-use FileHandle;
-    my $traceFile = new FileHandle('>test.trace') or die "Can't open test.trace file: $!";
-    select ($traceFile); $| = 1; select STDOUT;
-
 use strict;
 use WWW::Search::Scraper(qw(2.13));
 use WWW::Search::Scraper::Request;
@@ -67,9 +85,13 @@ use WWW::Search::Scraper::Request;
 for my $sEngine ( @modules ) {
     
     $iTest++;
-    TRACE("Test #$iTest: $sEngine\n");
+    TRACE(0, "Test #$iTest: $sEngine\n");
     my $oSearch = new WWW::Search::Scraper($sEngine);
-    print STDOUT ref($oSearch) ? '' : 'not ';
+    if ( not ref($oSearch)) {
+        TRACE(2, "Can't load scraper module for $sEngine: $!\n");
+        print STDOUT "not ok $iTest\n";
+        next;
+    }
     print STDOUT "ok $iTest\n";
 
 
@@ -82,17 +104,16 @@ for my $sEngine ( @modules ) {
 #######################################################################################
     $iTest++;
     my $iResults = 0;
-    # Brainpower.com and Dice.com return all jobs if you use Test::bogus_query.
-    unless ( $sEngine =~ m/Brainpower|Dice|Monster/ ) {
-        my ($sQuery, $options, $onePageCount, $multiPageCount, $bogusPageCount) = $oSearch->setupStandardAndExceptionalOptions($sEngine);
-        $sQuery = "Bogus" . $$ . "NoSuchWord" . time;
-        my $request = new WWW::Search::Scraper::Request($sQuery);
-        $oSearch->request($request);
-    
-        my @aoResults = $oSearch->results();
-        $iResults = scalar(@aoResults);
-        print STDOUT ( $bogusPageCount < $iResults ) ? 'not ' : '';
-        print STDERR " --- got $iResults 'bogus' results, expected 0\n" if $iResults > 0;
+    my ($sQuery, $options, $onePageCount, $multiPageCount, $bogusPageCount) = $oSearch->setupStandardAndExceptionalOptions($sEngine);
+    $sQuery = "Bogus" . $$ . "NoSuchWord" . time;
+    my $request = new WWW::Search::Scraper::Request($sQuery);
+    $oSearch->request($request);
+
+    my @aoResults = $oSearch->results();
+    $iResults = scalar(@aoResults);
+    if ( $bogusPageCount < $iResults ) {
+        TRACE (2, " --- got $iResults 'bogus' results, expected $bogusPageCount\n");
+        print "not ";
     }
     print STDOUT "ok $iTest\n";
 
@@ -124,12 +145,12 @@ for my $sEngine ( @modules ) {
             $iResults = scalar(@aoResults);
         };
 
-        TRACE(" + got $iResults results for $sQuery\n");
-        if ( $maximum_to_retrieve < $iResults )
-          {
-          print STDERR " --- got $iResults results for $sEngine ($sQuery), but expected $maximum_to_retrieve\n";
-          print STDOUT 'not ';
-          }
+        TRACE(0, " + got $iResults results for $sQuery\n");
+        if ( $maximum_to_retrieve > $iResults )
+        {
+            TRACE(2, " --- got $iResults results for $sEngine ($sQuery), but expected $maximum_to_retrieve\n");
+            print "not ";
+        }
     }
     print STDOUT "ok $iTest\n";
 
@@ -157,13 +178,13 @@ for my $sEngine ( @modules ) {
                 $iResults += 1;
             }
         };
-        TRACE(" ++ got $iResults results for $sQuery\n");
-        if (($iResults < $maximum_to_retrieve ))
+        TRACE(0, " ++ got $iResults multi-page results for $sQuery\n");
+        if ( $maximum_to_retrieve > $iResults )
           {
             # We make an exception for these jobsites, since
             #  they often turn up few Perl jobs, anyway.
-             unless ( $sEngine =~ m/Brainpower|computerjobs|guru|HotJobs|NorthernLight|Sherlock/ ) {
-                print STDERR " --- got $iResults results for multi-page $sEngine ($sQuery), but expected $maximum_to_retrieve..\n";
+             unless ( $sEngine =~ m/Brainpower|computerjobs|guru|HotJobs|NorthernLight/ ) {
+                TRACE(2, " --- got $iResults results for multi-page $sEngine ($sQuery), but expected $maximum_to_retrieve..\n");
                 print STDOUT 'not ';
             }
           }
@@ -171,54 +192,60 @@ for my $sEngine ( @modules ) {
     print STDOUT "ok $iTest\n";
     
 }
+    close $traceFile;
 
+    if ( $countWarningMessages and WWW::Search::Scraper::isGlennWood() ) {
+        print STDOUT "$countWarningMessages warning".(($countWarningMessages>1)?'s':'').". See file 'test.trace' for details.\n";
+    }
+    if ( $countErrorMessages ) {
+        print STDOUT "$countErrorMessages test".(($countErrorMessages>1)?'s':'')." failed. See file 'test.trace' for details.\n";
+    }
+    if ( $countErrorMessages ) {
+        open TMP, "<test.trace";
+        print join '', <TMP>;
+        close TMP;
+    }
 
 sub TRACE {
-    $traceFile->print($_[0]);
-    print $_[0] if WWW::Search::Scraper::isGlennWood();
+    $countWarningMessages += 1 if $_[0] == 1;
+    $countErrorMessages   += 1 if $_[0] == 2;
+    $traceFile->print($_[1]);
+    print $_[1] if WWW::Search::Scraper::isGlennWood();
 }
 
+
+
 { package WWW::Search::Scraper;
 # Set up standard, and exceptional, options.
 sub setupStandardAndExceptionalOptions {
     my ($oSearch, $sEngine) = @_;
 
-    $oSearch->techiesLocation('bayarea') if $sEngine eq 'techies'; # www.techies.com is special.
-    $oSearch->sherlockPlugin('http://sherlock.mozdev.org/yahoo.src') if $sEngine eq 'Sherlock'; # Sherlock is extra special.
-
-    my %specialQuery = (
-                         'apartments' => 'New York'
-                        ,'eBay'     => 'turntable'
-                        ,'Dice'     => 'Perl NOT Java'
-                        ,'Dogpile'  => 'Scraper'
-                        ,'Google'   => 'turntable'
-                        ,'HotJobs'  => 'Administrative Assistant'
-                        ,'Monster'  => 'Administrative Assistant'
-                        ,'FlipDog'  => 'Java'
-                        ,'BAJobs'   => 'Service'
-                        ,'Monster'  => 'Administrative Assistant'
-                        ,'Sherlock' => 'Greeting Cards'
-                       ); 
     my $sQuery = 'Perl';
-    $sQuery = $specialQuery{$sEngine} if defined $specialQuery{$sEngine};
-
-    my %specialOptions = (
-                             'apartments' => { 'state' => 'NY' }
-                            ,'JustTechJobs' => { 'whichTech' => 'Perl' }                                         
-                         );
-    my $options = $specialOptions{$sEngine};
-    $options = {} unless $options;
-
-    my %defaultPageCounts = (
-                                 'CraigsList' => (9,20,0)
-                                ,'Dogpile' => (9,50,0)
-                                ,'FlipDog' => (5,5,0)
-                                ,'techies' => (9,9,0)
-                            );
+    my $options;
     my $onePageCount = 9;
     my $multiPageCount = 41;
     my $bogusPageCount = 0;
-    ($onePageCount,$multiPageCount,$bogusPageCount) = $defaultPageCounts{$sEngine} if defined $defaultPageCounts{$sEngine};
+    my %specialOptions;
+    
+    # Most Scraper sub-classes will define their own testParameters . . .
+    # See Dogpile.pm for the most mature example of how to set your testParameters.
+    if ( my $testParameters = $oSearch->testParameters() ) {
+        $sQuery = $testParameters->{'testNativeQuery'} || $sQuery;
+        $options = $testParameters->{'testNativeOptions'};
+        $options = {} unless $options;
+        ($onePageCount,$multiPageCount,$bogusPageCount) = (9,41,0);
+        $onePageCount   = $testParameters->{'expectedOnePage'}   or $onePageCount;
+        $multiPageCount = $testParameters->{'expectedMultiPage'} or $multiPageCount;
+        $bogusPageCount = $testParameters->{'expectedBogusPage'} or $bogusPageCount;
+
+        return ($sQuery, $options, $onePageCount, $multiPageCount, $bogusPageCount);
+    }
+
+    # . . . others aren't ready for prime-time, so we hard wire their testParameters here.
+
+    my %specialQuery = (
+                       ); 
+    $sQuery = $specialQuery{$sEngine} if defined $specialQuery{$sEngine};
 
     return ($sQuery,$options,$onePageCount,$multiPageCount,$bogusPageCount);
 }
